"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class DeleteOperation {
    constructor(store, id) {
        this.store = store;
        this.identifier = id;
    }
    value(item) {
        if (typeof item === 'string') {
            this.identifier = item;
        }
        else {
            if (!item.hasMetadata()) {
                throw Error('Object\'s meta field is null');
            }
            this.identifier = item.meta.id;
        }
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.identifier == null) {
                throw new Error('Invalid parameters for DeleteOperation.');
            }
            return yield this.store.adapter.remove(this.identifier);
        });
    }
}
exports.DeleteOperation = DeleteOperation;
class BatchedDeleteOperation {
    constructor(store) {
        this.identifiers = [];
        this.store = store;
    }
    value(item) {
        if (typeof item === 'string') {
            this.identifiers.push(item);
        }
        else {
            if (!item.hasMetadata()) {
                throw Error('Item has no metadata.');
            }
            this.identifiers.push(item.meta.id);
        }
        return this;
    }
    values(item) {
        item.forEach(this.value);
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const items = [];
            for (const id of this.identifiers) {
                const value = yield new DeleteOperation(this.store).value(id).run();
                if (value) {
                    items.push(value);
                }
            }
            return items;
        });
    }
}
exports.BatchedDeleteOperation = BatchedDeleteOperation;
//# sourceMappingURL=delete.operation.js.map