"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class GetOperation {
    constructor(store) {
        this.filterMethod = (_) => true;
        this.paginationData = { skip: 0, take: Infinity };
        this.store = store;
    }
    filter(method) {
        this.filterMethod = method;
        return this;
    }
    id(id) {
        this.filterMethod = (v) => v.meta.id === id;
        return this;
    }
    paginate(data) {
        this.paginationData = data;
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const result = [];
            yield this.store.adapter.stream((value) => {
                const passedFilter = this.filterMethod(value);
                if (passedFilter) {
                    result.push(value);
                }
            });
            const skip = this.paginationData.skip || 0;
            const take = this.paginationData.take || Infinity;
            return result.slice(skip, skip + take);
        });
    }
    one() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.first();
        });
    }
    first() {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.run();
            return (result.length > 0) ? result[0] : null;
        });
    }
    last() {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield this.run();
            return (result.length > 0) ? result[result.length - 1] : null;
        });
    }
}
exports.GetOperation = GetOperation;
//# sourceMappingURL=get.operation.js.map