"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const metadata_utils_1 = require("../datastore/metadata.utils");
class PushOperation {
    constructor(store) {
        this.store = store;
    }
    item(value) {
        this.toAdd = value;
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.toAdd) {
                this.toAdd.meta = metadata_utils_1.MetadataUtils.getNewMetadata();
                return yield this.store.adapter.put(this.toAdd);
            }
            else {
                throw Error('Nothing is being pushed.');
            }
        });
    }
}
exports.PushOperation = PushOperation;
class BatchedPushOperation {
    constructor(store) {
        this.toAdd = [];
        this.store = store;
    }
    item(value) {
        this.toAdd.push(value);
        return this;
    }
    items(values) {
        values.forEach(this.item);
        return this;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            const items = [];
            for (const item of this.toAdd) {
                const value = yield new PushOperation(this.store).item(item).run();
                items.push(value);
            }
            return items;
        });
    }
}
exports.BatchedPushOperation = BatchedPushOperation;
//# sourceMappingURL=push.operation.js.map