"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const levelup_1 = __importDefault(require("levelup"));
const leveldown_1 = __importDefault(require("leveldown"));
const encoding_down_1 = __importDefault(require("encoding-down"));
const path_1 = require("path");
const class_transformer_1 = require("class-transformer");
class LevelDbAdapter {
    constructor(type, options) {
        this.type = type;
        this.name = options.name;
        this.level = levelup_1.default(encoding_down_1.default(leveldown_1.default(path_1.join(options.directory, options.name)), { valueEncoding: 'json' }));
    }
    convertToClass(item) {
        return class_transformer_1.plainToClass(this.type, item);
    }
    open() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.level.open();
        });
    }
    close() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.level.close();
        });
    }
    get(id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const item = yield this.level.get(id);
                const converted = this.convertToClass(item);
                return converted;
            }
            catch (e) {
                return null;
            }
        });
    }
    put(item) {
        return __awaiter(this, void 0, void 0, function* () {
            if (item.hasMetadata()) {
                const plain = class_transformer_1.classToPlain(item);
                yield this.level.put(item.meta.id, plain);
                return item;
            }
            else {
                throw Error('Item has no metadata');
            }
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const item = yield this.get(id);
            if (item == null) {
                return null;
            }
            yield this.level.del(id);
            return item;
        });
    }
    stream(callback) {
        return new Promise((resolve, reject) => {
            const stream = this.level.createReadStream();
            stream.on('end', () => {
                resolve();
            });
            stream.on('data', (item) => {
                callback(this.convertToClass(item.value));
            });
        });
    }
}
exports.LevelDbAdapter = LevelDbAdapter;
test('leveldb adapter', () => {
    expect(true).toBe(true);
});
//# sourceMappingURL=leveldb.adapter.test.js.map